<?php
/**
 * rallypro functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package rallypro
 */

if ( ! function_exists( 'rallypro_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function rallypro_setup() {
	/*
	 * Make theme available for translation.
	 * Translations can be filed in the /languages/ directory.
	 * If you're building a theme based on rallypro, use a find and replace
	 * to change 'rallypro' to the name of your theme in all the template files.
	 */
	load_theme_textdomain( 'rallypro', get_template_directory() . '/languages' );

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );

	/*
	 * Let WordPress manage the document title.
	 * By adding theme support, we declare that this theme does not use a
	 * hard-coded <title> tag in the document head, and expect WordPress to
	 * provide it for us.
	 */
	add_theme_support( 'title-tag' );

	/*
	 * Enable support for Post Thumbnails on posts and pages.
	 *
	 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
	 */
	add_theme_support( 'post-thumbnails' );

	// image size 

	add_image_size( 'rallypro_front_page_thumbnail', 555, 286, true );

	add_image_size( 'rallypro_main_page_thumbnail', 1200, 600, true );

	//adding custom field support globally

	add_theme_support( 'custom-fields' );

	// This theme uses wp_nav_menu() in one location.
	register_nav_menus( array(
		'primarymenu' => esc_html__( 'Primary', 'rallypro' ),
	) );

	/*
	 * Switch default core markup for search form, comment form, and comments
	 * to output valid HTML5.
	 */
	add_theme_support( 'html5', array(
		'search-form',
		'comment-form',
		'comment-list',
		'gallery',
		'caption',
	) );
	
	// Set up the WordPress core custom background feature.

	add_theme_support( 'custom-background', apply_filters( 'rallypro_custom_background_args', array(
		'default-color' => 'ffffff',
		'default-image' => '',
	) ) );

	// Add theme support for selective refresh for widgets.
	add_theme_support( 'customize-selective-refresh-widgets' );

	/**
	 * Add support for core custom logo.
	 *
	 * @link https://codex.wordpress.org/Theme_Logo
	 */
	add_theme_support( 'custom-logo', array(
		'height'      => 80,
		'width'       => 250,
		'flex-width'  => true,
		'flex-height' => true,
	) );

	//Add editor style 
	add_editor_style( 'css/custom-editor-style.css' );

}
endif;
add_action( 'after_setup_theme', 'rallypro_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function rallypro_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'rallypro_content_width', 640 );
}
add_action( 'after_setup_theme', 'rallypro_content_width', 0 );


/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function rallypro_widgets_init() {

	register_sidebar( array(
		'name'          => esc_html__( 'Sidebar' , 'rallypro' ),
		'id'            => 'sidebar',
		'description'   => esc_html__( 'Add widgets here.', 'rallypro' ),
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<div class="widget-title text-center"><h4>',
		'after_title'   => '</h4></div>',
	) );

	register_sidebar( array(
		'name'          => esc_html__( 'Footer 1' , 'rallypro' ),
		'id'            => 'footer-1',
		'description'   => esc_html__( 'Add widgets here.', 'rallypro' ),
		'before_widget' => '<div id="%1$s" class="sub-footer-content %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<div class="section-heading footer-head"><h4>',
		'after_title'   => '</h4></div>',
	) );

	register_sidebar( array(
		'name'          => esc_html__( 'Footer 2' , 'rallypro' ),
		'id'            => 'footer-2',
		'description'   => esc_html__( 'Add widgets here.', 'rallypro' ),
		'before_widget' => '<div id="%1$s" class="sub-footer-content text-center footer-follow-us animated wow zoomInUp %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<div class="section-heading footer-head"><h4>',
		'after_title'   => '</h4></div>',
	) );

	register_sidebar( array(
		'name'          => esc_html__( 'Footer 3' , 'rallypro' ),
		'id'            => 'footer-3',
		'description'   => esc_html__( 'Add widgets here.', 'rallypro' ),
		'before_widget' => '<div id="%1$s" class="sub-footer-content footer-contact-us %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<div class="section-heading footer-head"><h4>',
		'after_title'   => '</h4></div>',
	) );

}
add_action( 'widgets_init', 'rallypro_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
function rallypro_scripts() {
	
	//bootstrap-css

	wp_enqueue_style( 'bootstrap-css', get_template_directory_uri().'/css/bootstrap.css','3.3.7' );

	//animate-css

	wp_enqueue_style( 'animate-css', get_template_directory_uri().'/css/animate.css','3.5.2' );

	//ionicons-css

	wp_enqueue_style( 'ionicons-css', get_template_directory_uri().'/css/ionicons.css','2.0.0' );
	
	//style-css

	wp_enqueue_style( 'rallypro-css', get_stylesheet_uri() );

	//responsive-css

	wp_enqueue_style( 'rallypro-responsive-css', get_template_directory_uri().'/css/responsive.css');

	//wp-jquery

	wp_enqueue_script('jquery');

	//bootstrap-js

	wp_enqueue_script( 'jquery-bootstrap', get_template_directory_uri() . '/js/bootstrap.js', array(), '3.3.7', true );

	//wow-js

	wp_enqueue_script( 'jquery-wow', get_template_directory_uri() . '/js/wow.js', array(), '1.1.3', true );

	//custom-js

	wp_enqueue_script( 'rallypro-custom-script', get_template_directory_uri() . '/js/rallypro-custom.js', array(), true );

	wp_enqueue_script( 'rallypro-skip-link-focus-fix', get_template_directory_uri() . '/js/skip-link-focus-fix.js', array(), true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'rallypro_scripts' );


// For google fonts

function rallypro_load_fonts(){
	wp_register_style( 'google-fonts-Montserrat','https://fonts.googleapis.com/css?family=Montserrat:400,500,600,700');
	wp_enqueue_style('google-fonts-Montserrat');
}
add_action('wp_print_styles', 'rallypro_load_fonts');

/**
 * Add a pingback url auto-discovery header for singularly identifiable articles.
 */

function rallypro_pingback_header() {
	if ( is_singular() && pings_open() ) {
		echo '<link rel="pingback" href="', esc_url( get_bloginfo( 'pingback_url' ) ), '">';
	}
}
add_action( 'wp_head', 'rallypro_pingback_header' );

//remove hash link from read more button

function rallypro_remove_hash_link($link){
	$link = preg_replace('|#more-[0-9]+|','',$link);
	return $link;
}
add_filter('the_content_more_link','rallypro_remove_hash_link');

function rallypro_styling_read_more(){
	$style = '<a class="btn" href="'. esc_url( get_permalink() ) .'" role="button">' . __('continue reading', 'rallypro') .'</a>';
	return $style;
}
add_filter('the_content_more_link','rallypro_styling_read_more');	

// comment field to bottom

function rallypro_move_comment_field_to_bottom( $fields ) {
	$comment_field = $fields['comment'];
	unset( $fields['comment'] );
	$fields['comment'] = $comment_field;
	return $fields;
}
add_filter( 'comment_form_fields', 'rallypro_move_comment_field_to_bottom' );

// customize comment_form_defaults

function rallypro_comment_form_defaults( $defaults ) {
  $defaults['title_reply'] = __( 'Submit a Comment', 'rallypro' );
  $defaults['comment_notes_before'] = __( '<p>Must be required * marked fields.</p>', 'rallypro' );
  return $defaults;
}
add_filter( 'comment_form_defaults', 'rallypro_comment_form_defaults' );


//add class in next_posts_link and previous_posts_link

add_filter('next_posts_link_attributes', 'rallypro_posts_link_attributes_1');
add_filter('previous_posts_link_attributes', 'rallypro_posts_link_attributes_2');

function rallypro_posts_link_attributes_1() {
    return 'class="btn"';
}
function rallypro_posts_link_attributes_2() {
    return 'class="btn"';
}

/**
* To mute migrate console error
*/
add_action( 'wp_default_scripts', 'rallypro_jquery_migrate'  ) ;
    
	function rallypro_jquery_migrate($scripts){
	    if ( ! empty( $scripts->registered['jquery'] ) ) {
	        $scripts->registered['jquery']->deps = array_diff( $scripts->registered['jquery']->deps, array( 'jquery-migrate' ) );
	    }
	} 

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Add support for core custom Header.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Additional features to allow styling of the templates.
 */
require get_template_directory() . '/inc/template-functions.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
require get_template_directory() . '/inc/jetpack.php';

/**
*  Register Custom Navigation Walker
*/
require get_template_directory() . '/inc/class-wp-bootstrap-navwalker.php';

/**
*  Register Custom Comment walker class 
*/
require get_template_directory() . '/inc/class-wp-bootstrap-comment-walker.php';

/**
*  Add Custom CSS 
*/
require get_template_directory() . '/inc/custom-css.php';
