<?php
/**
 * rallypro Theme Customizer
 *
 * @package rallypro
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function rallypro_customize_register( $wp_customize ) {

	if ( ! function_exists( 'rallypro_sanitize_choices' ) ) :

	//Sanitize radio values

	function rallypro_sanitize_choices( $input, $setting ) {
	  
	  // Ensure input is a slug
	  $input = sanitize_key( $input );
	  
	  // Get list of choices from the control
	  // associated with the setting
	  $choices = $setting->manager->get_control( $setting->id )->choices;
	  
	  // If the input is a valid key, return it;
	  // otherwise, return the default
	  return ( array_key_exists( $input, $choices ) ? $input : $setting->default );
	}
	endif;

	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport = 'postMessage';

//Theme Help

	$wp_customize->add_section('theme_help', array(
	    'title' => __('Theme Help', 'rallypro'),
	    'priority' => 10,
	) );

	$wp_customize->add_setting('theme_help', array(
	    'default'     => '',
	    'transport'   => 'refresh',
	    'sanitize_callback' => 'wp_kses_post'
	));

	$theme_author_link = 'https://www.themerally.com/product/rally-pro-multipurpose-wordpress-theme-business-blogger/';

	$wp_customize->add_control( 'theme_help', array(
	  'label' => __('Welcome to Rally Pro Support!', 'rallypro'),
	  'section' => 'theme_help',
	  'settings' => 'theme_help',
	  'type' => 'hidden',
	  'description' => __('Rally Pro is a great theme for any business and blogger. You can use it to have more conversion to your site and business. For support and documentation please visit this link  : ' , 'rallypro'). '<a href="'.esc_url($theme_author_link).'" target="_blank">https://www.themerally.com/</a>'
	) );

// Layout Options

	$wp_customize->add_section( 'layout' ,array(
		'title' => __('Layout', 'rallypro'),
		'priority' => 20
	));
	$wp_customize->add_setting( 'layout_options' , array(
	      'default'     => 'right-sidebar',
	      'transport'   => 'refresh',
	      'sanitize_callback' => 'rallypro_sanitize_choices',
	  ) );

	$wp_customize->add_control( 'layout_options', array(
		  'label' => __('Select Your Layout', 'rallypro'),
		  'section' => 'layout',
		  'settings' => 'layout_options',
		  'type' => 'radio',
		  'choices' => array(
		    'right-sidebar' => __('Right Sidebar' , 'rallypro'),
		    'left-sidebar' => __('Left Sidebar' , 'rallypro'),
		    'full-width' => __('Full Width' , 'rallypro')
		  ),
	) );

//Journal Header

	$wp_customize->add_section( 'journal' ,array(
		'title' => __('Journal Header', 'rallypro'),
		'priority' => 20
	));
	$wp_customize->add_setting( 'journal_head' , array(
	      'default'     => ' ',
	      'transport'   => 'refresh',
	      'sanitize_callback' => 'esc_html',
	  ) );

	$wp_customize->add_control( 'journal_head', array(
		  'label' => __('Journal Heading', 'rallypro'),
		  'section' => 'journal',
		  'settings' => 'journal_head',
		  'type' => 'text',
	) );
	$wp_customize->add_setting( 'journal_description' , array(
	      'default'     => ' ',
	      'transport'   => 'refresh',
	      'sanitize_callback' => 'esc_html',
	  ) );

	$wp_customize->add_control( 'journal_description', array(
		  'label' => __('Journal Description', 'rallypro'),
		  'section' => 'journal',
		  'settings' => 'journal_description',
		  'type' => 'textarea',
	) );


//Footer Options

	$wp_customize->add_section( 'footer' , array(
	    'title'      => __('Footer', 'rallypro'),
	    'priority' => 21
	) );

	$wp_customize->add_setting( 'footer_copyright' , array(
	    'default'     => '',
	    'transport'   => 'refresh',
	    'sanitize_callback' => 'wp_kses_post'
	) );

	$wp_customize->add_control( 'footer_copyright', array(
	  'label' => __('Copyright Content', 'rallypro'),
	  'section' => 'footer',
	  'settings' => 'footer_copyright',
	  'type' => 'textarea'
	) );

}
add_action( 'customize_register', 'rallypro_customize_register' );

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function rallypro_customize_preview_js() {
	wp_enqueue_script( 'rallypro_customizer', get_template_directory_uri() . '/js/customizer.js', array( 'customize-preview' ), '20151215', true );
}
add_action( 'customize_preview_init', 'rallypro_customize_preview_js' );
